==> zio-aws-macie2_2.12-5.20.22.1-sources.jar: zio/aws/macie2/model/SearchResourcesCriteriaBlock.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SearchResourcesCriteriaBlock(
    and: Optional[Iterable[zio.aws.macie2.model.SearchResourcesCriteria]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock = {
    import SearchResourcesCriteriaBlock.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
      .builder()
      .optionallyWith(
        and.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.and)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.SearchResourcesCriteriaBlock.ReadOnly =
    zio.aws.macie2.model.SearchResourcesCriteriaBlock.wrap(buildAwsValue())
}
object SearchResourcesCriteriaBlock {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.SearchResourcesCriteriaBlock =
      zio.aws.macie2.model.SearchResourcesCriteriaBlock(
        and.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def and
        : Optional[List[zio.aws.macie2.model.SearchResourcesCriteria.ReadOnly]]
    def getAnd: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.SearchResourcesCriteria.ReadOnly
    ]] = AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
  ) extends zio.aws.macie2.model.SearchResourcesCriteriaBlock.ReadOnly {
    override val and: Optional[
      List[zio.aws.macie2.model.SearchResourcesCriteria.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.and())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.SearchResourcesCriteria.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
  ): zio.aws.macie2.model.SearchResourcesCriteriaBlock.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_2.13-5.17.115.1-sources.jar: zio/aws/macie2/model/SearchResourcesCriteriaBlock.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class SearchResourcesCriteriaBlock(
    and: Option[Iterable[zio.aws.macie2.model.SearchResourcesCriteria]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock = {
    import SearchResourcesCriteriaBlock.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
      .builder()
      .optionallyWith(
        and.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.and)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.SearchResourcesCriteriaBlock.ReadOnly =
    zio.aws.macie2.model.SearchResourcesCriteriaBlock.wrap(buildAwsValue())
}
object SearchResourcesCriteriaBlock {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.SearchResourcesCriteriaBlock =
      zio.aws.macie2.model.SearchResourcesCriteriaBlock(
        and.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def and: Option[List[zio.aws.macie2.model.SearchResourcesCriteria.ReadOnly]]
    def getAnd: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.SearchResourcesCriteria.ReadOnly
    ]] = AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
  ) extends zio.aws.macie2.model.SearchResourcesCriteriaBlock.ReadOnly {
    override val and
        : Option[List[zio.aws.macie2.model.SearchResourcesCriteria.ReadOnly]] =
      scala
        .Option(impl.and())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.macie2.model.SearchResourcesCriteria.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.SearchResourcesCriteriaBlock
  ): zio.aws.macie2.model.SearchResourcesCriteriaBlock.ReadOnly = new Wrapper(
    impl
  )
}
